
#include <stdlib.h>
#include <stdio.h>
#include <stdarg.h>
#include <string.h>
#include <limits.h>
#include <fx.h>
#include <stdint.h>
#include <FXPNGIcon.h>

static int app_created;

#include "gui.h"


#include "actions.h"


 

 typedef struct radio_item {
   struct radio_item *next;
   FXRadioButton *button;
   int value;
 } radio_item_t;

 typedef struct {
   int *target;
   radio_item_t *head;
 } FYRadioGroup;

static void radio_set_value (FYRadioGroup *G, int V)
{
  radio_item_t *T;
  for(T=G->head;T;T=T->next)
    if (T->value==V) 
     T->button->setCheck(TRUE);
    else T->button->setCheck(FALSE);
  G->target[0]= V;
}

static void radio_get_value (FYRadioGroup *G,int *R)
{
  *R= G->target[0];
}

static void radio_append(FYRadioGroup *G, FXRadioButton *B, int V)
{
  radio_item_t *T= (radio_item_t*) malloc(sizeof(*T));
  T->button= B;
  T->value= V;
  T->next= G->head;
  G->head= T;
}
  
  static FXFont *YQRZ_59;
   

  static FXFont *YQRZ_64;
   


  static FXFont *YQRZ_70;
   



class FYListItem : public FXListItem 
{
  FXDECLARE(FYListItem)
protected:
  FYListItem() : FXListItem() { }
public:
  FYListItem(const FXString& text,FXIcon* ic, void *pdata)
   : FXListItem(text,ic,NULL)
  { data_p= pdata; }
  FYListItem(const FXString& text,FXIcon* ic, int idata)
   : FXListItem(text,ic,NULL)
  { data_i= idata; }
  FYListItem(const FXString& text,FXIcon* ic, double fdata)
   : FXListItem(text,ic,NULL)
  { data_f= fdata; }
  ~FYListItem() { }
// These could be in a union, but who cares about space
  int data_i;
  double data_f;
  void *data_p;
};


FXIMPLEMENT(FYListItem,FXListItem,NULL,0)




static void clear_selection
  (FXList *L)
{
  int i;
  int N= L->getNumItems();
  for(i=0;i<N;i++)
    L->deselectItem(i);
}

static FYListItem* get_selected(FXList *L)
{
   int i, N= L->getNumItems();
   for(i=0;i<N;i++)
     if (L->isItemSelected(i))
       return (FYListItem*) L->getItem(i);
   return 0;
}




static inline FXList* list(gui_intlist_t *IL)
{
  return (FXList*) (IL->widget);
}

static int intlist_get_selected
   (gui_intlist_t* IL, int *ret)
{
  FYListItem *item= get_selected(list(IL));
  if (item) { *ret= item->data_i; return 1; }
  return 0;
}

static void intlist_clear(gui_intlist_t* IL)
{
  list(IL)->clearItems();
}

static int intlist_find_item(gui_intlist_t *IL, int key)
{
  int i;
  FXList* L= list(IL);
  int N= L->getNumItems();
  for(i=0;i<N;i++)
    {
        FYListItem *it= (FYListItem*) L->getItem(i);
        if (it->data_i==key) return i;
    }
  return -1;
}

static int intlist_select_item
  (gui_intlist_t *IL, int key,int sel)
{
  int i= intlist_find_item(IL, key); 
  if (i==-1) return 0;
  if (sel) list(IL)->selectItem(i);
  else list(IL)->deselectItem(i); 
  return 1;
}


static void intlist_append_item
  (gui_intlist_t *IL, const char *text, int key)
{
  list(IL)->appendItem(new FYListItem(text, NULL,key));
}

static void intlist_prepend_item
  (gui_intlist_t *IL, const char *text, int key)
{
  list(IL)->prependItem(new FYListItem(text, NULL,key));
}

static void intlist_insert_item
  (gui_intlist_t *IL, int poskey, const char *text, int key)
{
  int i= intlist_find_item(IL, poskey);
  if (i!=-1)
    list(IL)->insertItem(i, new FYListItem(text, NULL, key));
  else
    list(IL)->appendItem(new FYListItem(text, NULL, key));
}

static void intlist_clear_selection(gui_intlist_t *IL)
{
  clear_selection(list(IL));
}

static void intlist_remove_item(gui_intlist_t *IL, int key)
{
  int i= intlist_find_item(IL, key);
  if (i==-1) return ;
  list(IL)->removeItem(i);
}

static gui_intlist_class_t gui_intlist_class=
{
   intlist_get_selected,
   intlist_select_item,
   intlist_clear_selection,
   intlist_append_item,
   intlist_prepend_item,
   intlist_insert_item,
   intlist_remove_item,
   intlist_clear,
};



static FXList* list(gui_sslist_t *SL)
{
  return (FXList*) SL->widget;
}

static int sslist_get_selected(gui_sslist_t *SL, char **ret)
{
  FYListItem *item= get_selected(list(SL));
  if (!item) return 0;
  *ret= (char*) item->data_p;
  return 1;
}

static int sslist_find_item(gui_sslist_t *SL,const char *key)
{
  FXList *L= list(SL);
  int i, N= L->getNumItems();
  for(i=0;i<N;i++) {
    FYListItem* item= (FYListItem*) L->getItem(i);
    if (!strcmp((char*) item->data_p, key)) return i;
  }
  return -1;
}

static void sslist_append_item(gui_sslist_t *SL, const char *value)
{
  list(SL)->appendItem(new FYListItem(value, NULL, (void*) value));
}
static void sslist_prepend_item(gui_sslist_t *SL, const char *value)
{
  list(SL)->prependItem(new FYListItem(value, NULL, (void*) value));
}
static void sslist_insert_item
      (gui_sslist_t *SL, const char *poskey, const char *value)
{
  int i= sslist_find_item(SL, poskey);
  if (i==-1) sslist_append_item(SL, value);
  else list(SL)->insertItem(i,new FYListItem(value, NULL, (void*) value));
}

static gui_sslist_class_t gui_sslist_class= {
  sslist_get_selected,
  sslist_append_item,
  sslist_prepend_item,
  sslist_insert_item
};



static FXList* list(gui_slist_t *SL)
{
  return (FXList*) SL->widget;
}

static int slist_get_selected(gui_slist_t *SL, char **ret)
{
  FYListItem *item= get_selected(list(SL));
  if (!item) return 0;
  *ret= (char*) item->data_p;
  return 1;
}

static int slist_find_item(gui_slist_t *SL,const char *key)
{
  FXList *L= list(SL);
  int i, N= L->getNumItems();
  for(i=0;i<N;i++) {
    FYListItem* item= (FYListItem*) L->getItem(i);
    if (!strcmp((char*) item->data_p, key)) return i;
  }
  return -1;
}

static void slist_append_item
    (gui_slist_t *SL, const char *value, const char *data)
{
  list(SL)->appendItem(new FYListItem(value, NULL, (void*) data));
}

static void slist_prepend_item
   (gui_slist_t *SL, const char *value,const char *data)
{
  list(SL)->prependItem(new FYListItem(value, NULL, (void*) data));
}

static void slist_insert_item
      (gui_slist_t *SL, const char *poskey,
       const char *value,const char *data)
{
  int i= slist_find_item(SL, poskey);
  if (i==-1) slist_append_item(SL, value,data);
  else list(SL)->insertItem(i,new FYListItem(value, NULL, (void*) data));
}

static void slist_remove_item
      (gui_slist_t *SL, const char *key)
{
  int i= slist_find_item(SL, key);
  if (i!=-1)
     list(SL)->removeItem(i);
}

static gui_slist_class_t gui_slist_class= {
  slist_get_selected,
  slist_append_item,
  slist_prepend_item,
  slist_insert_item,
  slist_remove_item,
};


static int item_type(FXDirItem *item)
{
  if (item->isDirectory()) return 'D';
  if (item->isSymlink())   return 'L';
  if (item->isChardev())   return 'C';
  if (item->isBlockdev())  return 'B';
  if (item->isFifo())      return 'P';
  if (item->isSocket())    return 'S';
  return 'F';
}
  

static int item_type(FXFileList *L, int item)
{
  if (L->isItemDirectory(item)) return 'D';
  return 'F';
}
  


class FYListItem_i : public FXListItem 
{
  FXDECLARE(FYListItem_i)
protected:
  FYListItem_i() : FXListItem() { }
public:
  FYListItem_i(const FXString& text,FXIcon* ic, int idata)
   : FXListItem(text,ic,NULL)
  { data_i= idata; }
  ~FYListItem_i() { }
  int data_i;
};
FXIMPLEMENT(FYListItem_i,FXListItem,NULL,0)

static FYListItem_i* intlist_get_selected(FXList *L)
{
   int i, N= L->getNumItems();
   for(i=0;i<N;i++)
     if (L->isItemSelected(i))
       return (FYListItem_i*) L->getItem(i);
   return NULL;
}
static int intlist_find_item(FXList *L, int key)
{
  int i;
  int N= L->getNumItems();
  for(i=0;i<N;i++)
    {
        FYListItem *it= (FYListItem*) L->getItem(i);
        if (it->data_i==key) return i;
    }
  return -1;
}
  

 
 static void YQRZ_7(gui_radio_group_t *_object , int V)
 {
    FYRadioGroup *widget= (FYRadioGroup*) (_object->widget);
     radio_set_value(widget, V); 
 }

 static void YQRZ_8(gui_radio_group_t *_object , int *R)
 {
    FYRadioGroup *widget= (FYRadioGroup*) (_object->widget);
     radio_get_value(widget, R); 
 }


 static void YQRZ_1(gui_button_t *_object ,  const char *text )
 {
    FXButton *widget= (FXButton*) (_object->widget);
    
      widget->setText(text);
   
 }


 static void YQRZ_33(gui_newbutton_t *_object ,  const char * value )
 {
    FXButton *widget= (FXButton*) (_object->widget);
     widget->setText(value); 
 }


 static void YQRZ_5(gui_text_field_t *_object ,  const char *text )
 {
    FXTextField *widget= (FXTextField*) (_object->widget);
    
     widget->setText(text);
  
 }

 static void YQRZ_6(gui_text_field_t *_object ,  char **result )
 {
    FXTextField *widget= (FXTextField*) (_object->widget);
    
    FXString S= widget->getText();
    *result= strdup(S.text());
  
 }


 static void YQRZ_20(gui_message_console_t *_object , const char *fmt, ...)
 {
    FXText *widget= (FXText*) (_object->widget);
    
   int size=200; char *message; int len; char *atmp;
   va_list ap;
   message= (char*) malloc(size);
   while(1) {
     va_start(ap,fmt);
     len= vsnprintf(message,size, fmt, ap);
     va_end(ap);
     if (len<0) size*= 2;
     else if (len<size) break;
     else size= len+2;
     message= (char*) realloc(atmp= message, size);
     if (!message) {
        free(atmp);
        message= (char*) fmt;
        break;
     }
    } 
    widget->appendText(message, strlen(message));
    if (message!=fmt) free(message);
     // argh, AUTOSCROLL doesn`t work yet. see
     // http://ruby.11.n6.nabble.com/TEXT-AUTOSCROLL-in-FXText-with-usage-of-FXDataTarget-td3510118.html
    widget->makePositionVisible(widget->getLength()-1);
  
 }

 static void YQRZ_21(gui_message_console_t *_object , const char *str, size_t len)
 {
    FXText *widget= (FXText*) (_object->widget);
    
    //If somebody does their own formatting, they will want to print bytes
    //directly. So, this one does that.
    widget->appendText(str, len);
     // argh, AUTOSCROLL doesn`t work yet. see
     // http://ruby.11.n6.nabble.com/TEXT-AUTOSCROLL-in-FXText-with-usage-of-FXDataTarget-td3510118.html
    widget->makePositionVisible(widget->getLength()-1);
  
 }

 static void YQRZ_22(gui_message_console_t *_object  )
 {
    FXText *widget= (FXText*) (_object->widget);
    
    widget->removeText(0, widget->getLength()); 
  
 }


 static void YQRZ_17(gui_dir_list_t *_object , const char *fn)
 {
    FXDirList *widget= (FXDirList*) (_object->widget);
     widget->setCurrentFile(fn); 
 }

 static void YQRZ_18(gui_dir_list_t *_object , const char *fn)
 {
    FXDirList *widget= (FXDirList*) (_object->widget);
     widget->setDirectory(fn); 
 }

 static void YQRZ_19(gui_dir_list_t *_object , int *result, const char **name, int *type)
 {
    FXDirList *widget= (FXDirList*) (_object->widget);
    
    FXDirItem *item= (FXDirItem*) (widget->getCurrentItem());
    *result= 0;
    if (!item) return ;
    if (name) *name= strdup(widget->getItemPathname(item).text());
    if (type) *type= item_type(item);
    *result= 1;
  
 }


 static void YQRZ_13(gui_file_list_t *_object ,  int *Rresult, const char **Rname, int *Rtype )
 {
    FXFileList *widget= (FXFileList*) (_object->widget);
    
    FXString cur;
    int item;

    item= widget->getCurrentItem();
    if (item<0) { *Rresult= 0; return ; }
    cur= widget->getCurrentFile();
    if (Rname) *Rname= strdup(cur.text());
    if (Rtype) *Rtype= item_type(widget,item);
    *Rresult= 1;
  
 }

 static void YQRZ_14(gui_file_list_t *_object ,  const char *fn )
 {
    FXFileList *widget= (FXFileList*) (_object->widget);
    
    widget->setCurrentFile(fn);
  
 }

 static void YQRZ_15(gui_file_list_t *_object ,  const char *fn )
 {
    FXFileList *widget= (FXFileList*) (_object->widget);
     widget->setDirectory(fn); 
 }

 static void YQRZ_16(gui_file_list_t *_object ,  char **fn )
 {
    FXFileList *widget= (FXFileList*) (_object->widget);
    
    FXString cur;
    cur= widget->getDirectory();
    if (fn) *fn= strdup(cur.text());
  
 }


 static void YQRZ_25(gui_int_list_t *_object  )
 {
    FXList *widget= (FXList*) (_object->widget);
    
    int i,N;
    N= widget->getNumItems();
    for(i=0;i<N;i++) widget->deselectItem(i);
  
 }

 static void YQRZ_26(gui_int_list_t *_object , int *R, int *key)
 {
    FXList *widget= (FXList*) (_object->widget);
    
    FYListItem_i *item= intlist_get_selected(widget);
    if (item) { *key= item->data_i; *R= 1; }
    else        *R= 0;
  
 }

 static void YQRZ_27(gui_int_list_t *_object ,  int key, int sel )
 {
    FXList *widget= (FXList*) (_object->widget);
    
     int i= intlist_find_item(widget, key); 
     if (i==-1) return ;
     if (sel) widget->selectItem(i);
         else widget->deselectItem(i); 
  
 }

 static void YQRZ_28(gui_int_list_t *_object ,  const char *text, int key )
 {
    FXList *widget= (FXList*) (_object->widget);
     widget->appendItem(new FYListItem_i(text, NULL,key)); 
 }

 static void YQRZ_29(gui_int_list_t *_object ,  const char *text, int key )
 {
    FXList *widget= (FXList*) (_object->widget);
     widget->prependItem(new FYListItem_i(text, NULL,key)); 
 }

 static void YQRZ_30(gui_int_list_t *_object ,  int poskey, const char *text, int key )
 {
    FXList *widget= (FXList*) (_object->widget);
    
    int i= intlist_find_item(widget, poskey);
    if (i!=-1)
      widget->insertItem(i, new FYListItem_i(text, NULL, key));
    else
      widget->appendItem(new FYListItem_i(text, NULL, key));
  
 }

 static void YQRZ_31(gui_int_list_t *_object ,  int key )
 {
    FXList *widget= (FXList*) (_object->widget);
    
    int i= intlist_find_item(widget, key);
    if (i==-1) return ;
    widget->removeItem(i);
  
 }

 static void YQRZ_32(gui_int_list_t *_object  )
 {
    FXList *widget= (FXList*) (_object->widget);
     widget->clearItems(); 
 }


 

static gui_radio_group_class_t gui_radio_group_class = {
        YQRZ_7,
       YQRZ_8,

};




static gui_button_class_t gui_button_class = {
        YQRZ_1,

};




static gui_newbutton_class_t gui_newbutton_class = {
        YQRZ_33,

};



  static FXIcon *VFLL5;
  static unsigned char YQRZ_66 []= {
0x89,0x50,0x4e,0x47,0x0d,0x0a,0x1a,0x0a,0x00,0x00,
0x00,0x0d,0x49,0x48,0x44,0x52,0x00,0x00,0x00,0x10,
0x00,0x00,0x00,0x10,0x08,0x06,0x00,0x00,0x00,0x1f,
0xf3,0xff,0x61,0x00,0x00,0x00,0x09,0x70,0x48,0x59,
0x73,0x00,0x00,0x0b,0x13,0x00,0x00,0x0b,0x13,0x01,
0x00,0x9a,0x9c,0x18,0x00,0x00,0x00,0x20,0x63,0x48,
0x52,0x4d,0x00,0x00,0x7a,0x25,0x00,0x00,0x80,0x83,
0x00,0x00,0xf9,0xff,0x00,0x00,0x80,0xe9,0x00,0x00,
0x75,0x30,0x00,0x00,0xea,0x60,0x00,0x00,0x3a,0x98,
0x00,0x00,0x17,0x6f,0x92,0x5f,0xc5,0x46,0x00,0x00,
0x02,0xc5,0x49,0x44,0x41,0x54,0x78,0xda,0x5c,0x93,
0x3f,0x68,0x9d,0x55,0x14,0xc0,0x7f,0xe7,0xde,0xfb,
0xfd,0x79,0xaf,0x2f,0x24,0x79,0x95,0x97,0xb4,0x83,
0xa0,0x0d,0x04,0x8a,0x58,0x44,0x10,0x11,0x4c,0x41,
0x44,0x70,0xd5,0xa5,0x16,0x4b,0xe6,0xae,0x85,0xb8,
0x28,0x34,0x74,0xec,0xd0,0xdd,0xc1,0x49,0xa8,0x9b,
0x0e,0x2e,0x4e,0x42,0x3b,0x88,0xc9,0x22,0x8a,0x94,
0x56,0x28,0x76,0x4a,0x49,0xa0,0x2f,0x11,0xdf,0xf7,
0xde,0x77,0xff,0x7c,0xf7,0x38,0x7c,0x89,0x82,0x07,
0x2e,0x07,0xee,0x39,0xe7,0x37,0x9c,0x7b,0x7f,0xb2,
0xb7,0xf7,0x33,0xff,0x8b,0xcb,0x65,0x59,0x5e,0xaf,
0xab,0x7a,0xcb,0x3a,0x77,0x11,0x20,0xa5,0x78,0xd0,
0xb6,0xed,0xc3,0x10,0xc2,0x7d,0x55,0x7d,0x24,0x22,
0xa8,0x2a,0x00,0x72,0x06,0x50,0x55,0x5b,0x95,0xd5,
0xee,0xea,0xea,0xea,0xad,0xe1,0xb9,0x73,0x43,0x67,
0x2d,0x88,0x9c,0xd5,0xe8,0x52,0xa2,0x69,0x9a,0xf9,
0xf4,0x78,0x7a,0xcf,0x87,0xb0,0x2b,0xd0,0x01,0x38,
0x80,0x9c,0xb3,0x1b,0x8d,0x46,0x5f,0x4f,0x26,0x93,
0x6b,0x45,0x51,0x22,0x00,0x22,0x7d,0x06,0x54,0x04,
0x29,0x0a,0x96,0x57,0x56,0x86,0x83,0xe1,0xe0,0x8b,
0xc3,0xc3,0xc3,0x8d,0xa6,0x69,0x6e,0x88,0x48,0x32,
0xaa,0xca,0xa0,0x1e,0xdc,0x9e,0x4c,0xd6,0xfa,0x61,
0x11,0x0a,0x67,0x59,0xae,0x1d,0x85,0xb3,0x18,0x6b,
0xb1,0xc6,0x60,0x8d,0x41,0x44,0x28,0xcb,0x8a,0xb5,
0xc9,0xfa,0xb5,0xaa,0xaa,0x6e,0xab,0x2a,0xc6,0x88,
0xd9,0x1c,0x8f,0xc7,0x3b,0x45,0x51,0x20,0x22,0xd4,
0x85,0xe5,0xf1,0x49,0xe2,0xcb,0xdf,0x1b,0xc4,0x5a,
0x96,0x06,0x05,0xce,0xb9,0x1e,0x64,0x0d,0xc6,0x18,
0xaa,0xba,0x64,0x3c,0x3e,0xbf,0x23,0x22,0x9b,0xa6,
0xaa,0xab,0xed,0xe1,0x70,0x58,0x01,0x7d,0xd1,0x1a,
0xfe,0x8a,0x70,0xf3,0xc7,0x63,0xde,0xff,0xee,0x90,
0x1f,0xfe,0x6c,0xa8,0x8c,0xe2,0x34,0xd1,0xb6,0x9e,
0xe0,0x3d,0x29,0x75,0x8c,0x46,0xa3,0xaa,0xae,0xeb,
0x6d,0x37,0xa8,0x07,0x57,0x8d,0xb5,0x18,0x11,0x44,
0x04,0x31,0x86,0xd2,0x18,0x30,0x99,0x9f,0x9e,0xcd,
0xf8,0xf0,0xe9,0x94,0x8f,0x5e,0xad,0xf8,0xec,0xad,
0x31,0xaf,0xbf,0x54,0x70,0xd2,0x78,0x16,0x21,0x60,
0xad,0xa5,0x2c,0xca,0xab,0xc6,0x39,0x77,0xe1,0xec,
0xfd,0xce,0x96,0xd7,0x75,0x1d,0xf8,0x05,0x68,0x00,
0x4d,0x7c,0xfb,0xdb,0x0b,0xb6,0xbe,0x7a,0xcc,0xcd,
0xef,0x9f,0x71,0xec,0x33,0x85,0xb5,0x2c,0xe6,0x0b,
0xbc,0xf7,0x17,0xdc,0xbf,0xab,0x96,0x7e,0x38,0xc5,
0x48,0x8a,0x01,0x82,0xef,0xef,0x73,0x07,0x31,0x82,
0xcd,0xa0,0x0a,0x7a,0xda,0x6e,0x0c,0x00,0x2e,0xa5,
0xf4,0x1c,0x78,0xa5,0xef,0xed,0xf0,0x31,0xa2,0x5d,
0x07,0xde,0x43,0xe8,0xc0,0x28,0x1f,0xbf,0x36,0x66,
0xe7,0xdd,0x75,0xae,0x4c,0x2a,0x4e,0x66,0x2d,0x73,
0x1f,0xd0,0x9c,0x51,0xd5,0xe7,0xae,0x6d,0xdb,0x07,
0x39,0xe7,0x77,0x8c,0x58,0x7c,0xf4,0x14,0x64,0x7c,
0x88,0xf0,0xf7,0x9c,0xb7,0x2f,0x2d,0xf3,0xf9,0x7b,
0x2f,0xf3,0xc1,0xc6,0x32,0x21,0x25,0x8e,0x1b,0x4f,
0x4c,0x1d,0x9a,0x33,0xb9,0x3f,0x0f,0x64,0x7f,0x7f,
0x6f,0x73,0x7d,0xfd,0xc2,0xaf,0x4b,0x4b,0x4b,0xd5,
0x6c,0x36,0xc3,0x09,0xfc,0x31,0x0d,0xfc,0x72,0x30,
0xe7,0xd3,0x37,0xd7,0x18,0x16,0x86,0x99,0x4f,0xa4,
0xd4,0x91,0xba,0x44,0x8a,0x89,0x98,0x22,0x8b,0xf9,
0xc2,0xfb,0xe0,0xaf,0x18,0x55,0x7d,0x72,0x3c,0x7d,
0x71,0x37,0x86,0x40,0x8a,0x91,0xb9,0x0f,0x5c,0x5a,
0x71,0x6c,0xbf,0x71,0x9e,0x18,0x23,0xd3,0x59,0x4b,
0x08,0x91,0x98,0xe2,0x29,0xa4,0x23,0x86,0x48,0x8c,
0xf1,0xae,0xaa,0x3e,0x71,0x22,0x42,0xeb,0xfd,0x9d,
0xa3,0xa3,0xa3,0x0d,0xe7,0xdc,0x27,0x22,0x02,0xaa,
0x84,0xd4,0xf5,0x2a,0x28,0x28,0x4a,0xce,0x4a,0xd7,
0x25,0x62,0x88,0xb4,0xbe,0xfd,0x26,0x6b,0xbe,0x23,
0x22,0xbd,0x0b,0x22,0x92,0xe6,0xf3,0xe6,0x86,0x31,
0xf6,0x69,0x51,0x14,0xb7,0x5c,0xe1,0x86,0xd6,0x5a,
0x7a,0xd8,0xa9,0x4c,0x5d,0x47,0x4a,0x69,0x1e,0x63,
0xb8,0xd7,0xe5,0xbc,0xcb,0xa9,0x4c,0xb2,0xbf,0xbf,
0xf7,0xdf,0x1f,0x38,0xd5,0xd9,0x88,0xb9,0x2e,0xc6,
0x6c,0x19,0x23,0x17,0xb5,0x07,0x1c,0xe4,0xdc,0x3d,
0xcc,0xaa,0xf7,0x81,0x47,0x67,0x2a,0x03,0xfc,0x33,
0x00,0x66,0xd5,0x75,0x1e,0x14,0x77,0xfd,0xd6,0x00,
0x00,0x00,0x00,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,
0x82,

  };

  static FXIcon *VFLL6;
  static unsigned char YQRZ_73 []= {
0x89,0x50,0x4e,0x47,0x0d,0x0a,0x1a,0x0a,0x00,0x00,
0x00,0x0d,0x49,0x48,0x44,0x52,0x00,0x00,0x00,0x10,
0x00,0x00,0x00,0x10,0x08,0x06,0x00,0x00,0x00,0x1f,
0xf3,0xff,0x61,0x00,0x00,0x00,0x09,0x70,0x48,0x59,
0x73,0x00,0x00,0x0b,0x13,0x00,0x00,0x0b,0x13,0x01,
0x00,0x9a,0x9c,0x18,0x00,0x00,0x00,0x20,0x63,0x48,
0x52,0x4d,0x00,0x00,0x7a,0x25,0x00,0x00,0x80,0x83,
0x00,0x00,0xf9,0xff,0x00,0x00,0x80,0xe9,0x00,0x00,
0x75,0x30,0x00,0x00,0xea,0x60,0x00,0x00,0x3a,0x98,
0x00,0x00,0x17,0x6f,0x92,0x5f,0xc5,0x46,0x00,0x00,
0x02,0xc5,0x49,0x44,0x41,0x54,0x78,0xda,0x5c,0x93,
0x3f,0x68,0x9d,0x55,0x14,0xc0,0x7f,0xe7,0xde,0xfb,
0xfd,0x79,0xaf,0x2f,0x24,0x79,0x95,0x97,0xb4,0x83,
0xa0,0x0d,0x04,0x8a,0x58,0x44,0x10,0x11,0x4c,0x41,
0x44,0x70,0xd5,0xa5,0x16,0x4b,0xe6,0xae,0x85,0xb8,
0x28,0x34,0x74,0xec,0xd0,0xdd,0xc1,0x49,0xa8,0x9b,
0x0e,0x2e,0x4e,0x42,0x3b,0x88,0xc9,0x22,0x8a,0x94,
0x56,0x28,0x76,0x4a,0x49,0xa0,0x2f,0x11,0xdf,0xf7,
0xde,0x77,0xff,0x7c,0xf7,0x38,0x7c,0x89,0x82,0x07,
0x2e,0x07,0xee,0x39,0xe7,0x37,0x9c,0x7b,0x7f,0xb2,
0xb7,0xf7,0x33,0xff,0x8b,0xcb,0x65,0x59,0x5e,0xaf,
0xab,0x7a,0xcb,0x3a,0x77,0x11,0x20,0xa5,0x78,0xd0,
0xb6,0xed,0xc3,0x10,0xc2,0x7d,0x55,0x7d,0x24,0x22,
0xa8,0x2a,0x00,0x72,0x06,0x50,0x55,0x5b,0x95,0xd5,
0xee,0xea,0xea,0xea,0xad,0xe1,0xb9,0x73,0x43,0x67,
0x2d,0x88,0x9c,0xd5,0xe8,0x52,0xa2,0x69,0x9a,0xf9,
0xf4,0x78,0x7a,0xcf,0x87,0xb0,0x2b,0xd0,0x01,0x38,
0x80,0x9c,0xb3,0x1b,0x8d,0x46,0x5f,0x4f,0x26,0x93,
0x6b,0x45,0x51,0x22,0x00,0x22,0x7d,0x06,0x54,0x04,
0x29,0x0a,0x96,0x57,0x56,0x86,0x83,0xe1,0xe0,0x8b,
0xc3,0xc3,0xc3,0x8d,0xa6,0x69,0x6e,0x88,0x48,0x32,
0xaa,0xca,0xa0,0x1e,0xdc,0x9e,0x4c,0xd6,0xfa,0x61,
0x11,0x0a,0x67,0x59,0xae,0x1d,0x85,0xb3,0x18,0x6b,
0xb1,0xc6,0x60,0x8d,0x41,0x44,0x28,0xcb,0x8a,0xb5,
0xc9,0xfa,0xb5,0xaa,0xaa,0x6e,0xab,0x2a,0xc6,0x88,
0xd9,0x1c,0x8f,0xc7,0x3b,0x45,0x51,0x20,0x22,0xd4,
0x85,0xe5,0xf1,0x49,0xe2,0xcb,0xdf,0x1b,0xc4,0x5a,
0x96,0x06,0x05,0xce,0xb9,0x1e,0x64,0x0d,0xc6,0x18,
0xaa,0xba,0x64,0x3c,0x3e,0xbf,0x23,0x22,0x9b,0xa6,
0xaa,0xab,0xed,0xe1,0x70,0x58,0x01,0x7d,0xd1,0x1a,
0xfe,0x8a,0x70,0xf3,0xc7,0x63,0xde,0xff,0xee,0x90,
0x1f,0xfe,0x6c,0xa8,0x8c,0xe2,0x34,0xd1,0xb6,0x9e,
0xe0,0x3d,0x29,0x75,0x8c,0x46,0xa3,0xaa,0xae,0xeb,
0x6d,0x37,0xa8,0x07,0x57,0x8d,0xb5,0x18,0x11,0x44,
0x04,0x31,0x86,0xd2,0x18,0x30,0x99,0x9f,0x9e,0xcd,
0xf8,0xf0,0xe9,0x94,0x8f,0x5e,0xad,0xf8,0xec,0xad,
0x31,0xaf,0xbf,0x54,0x70,0xd2,0x78,0x16,0x21,0x60,
0xad,0xa5,0x2c,0xca,0xab,0xc6,0x39,0x77,0xe1,0xec,
0xfd,0xce,0x96,0xd7,0x75,0x1d,0xf8,0x05,0x68,0x00,
0x4d,0x7c,0xfb,0xdb,0x0b,0xb6,0xbe,0x7a,0xcc,0xcd,
0xef,0x9f,0x71,0xec,0x33,0x85,0xb5,0x2c,0xe6,0x0b,
0xbc,0xf7,0x17,0xdc,0xbf,0xab,0x96,0x7e,0x38,0xc5,
0x48,0x8a,0x01,0x82,0xef,0xef,0x73,0x07,0x31,0x82,
0xcd,0xa0,0x0a,0x7a,0xda,0x6e,0x0c,0x00,0x2e,0xa5,
0xf4,0x1c,0x78,0xa5,0xef,0xed,0xf0,0x31,0xa2,0x5d,
0x07,0xde,0x43,0xe8,0xc0,0x28,0x1f,0xbf,0x36,0x66,
0xe7,0xdd,0x75,0xae,0x4c,0x2a,0x4e,0x66,0x2d,0x73,
0x1f,0xd0,0x9c,0x51,0xd5,0xe7,0xae,0x6d,0xdb,0x07,
0x39,0xe7,0x77,0x8c,0x58,0x7c,0xf4,0x14,0x64,0x7c,
0x88,0xf0,0xf7,0x9c,0xb7,0x2f,0x2d,0xf3,0xf9,0x7b,
0x2f,0xf3,0xc1,0xc6,0x32,0x21,0x25,0x8e,0x1b,0x4f,
0x4c,0x1d,0x9a,0x33,0xb9,0x3f,0x0f,0x64,0x7f,0x7f,
0x6f,0x73,0x7d,0xfd,0xc2,0xaf,0x4b,0x4b,0x4b,0xd5,
0x6c,0x36,0xc3,0x09,0xfc,0x31,0x0d,0xfc,0x72,0x30,
0xe7,0xd3,0x37,0xd7,0x18,0x16,0x86,0x99,0x4f,0xa4,
0xd4,0x91,0xba,0x44,0x8a,0x89,0x98,0x22,0x8b,0xf9,
0xc2,0xfb,0xe0,0xaf,0x18,0x55,0x7d,0x72,0x3c,0x7d,
0x71,0x37,0x86,0x40,0x8a,0x91,0xb9,0x0f,0x5c,0x5a,
0x71,0x6c,0xbf,0x71,0x9e,0x18,0x23,0xd3,0x59,0x4b,
0x08,0x91,0x98,0xe2,0x29,0xa4,0x23,0x86,0x48,0x8c,
0xf1,0xae,0xaa,0x3e,0x71,0x22,0x42,0xeb,0xfd,0x9d,
0xa3,0xa3,0xa3,0x0d,0xe7,0xdc,0x27,0x22,0x02,0xaa,
0x84,0xd4,0xf5,0x2a,0x28,0x28,0x4a,0xce,0x4a,0xd7,
0x25,0x62,0x88,0xb4,0xbe,0xfd,0x26,0x6b,0xbe,0x23,
0x22,0xbd,0x0b,0x22,0x92,0xe6,0xf3,0xe6,0x86,0x31,
0xf6,0x69,0x51,0x14,0xb7,0x5c,0xe1,0x86,0xd6,0x5a,
0x7a,0xd8,0xa9,0x4c,0x5d,0x47,0x4a,0x69,0x1e,0x63,
0xb8,0xd7,0xe5,0xbc,0xcb,0xa9,0x4c,0xb2,0xbf,0xbf,
0xf7,0xdf,0x1f,0x38,0xd5,0xd9,0x88,0xb9,0x2e,0xc6,
0x6c,0x19,0x23,0x17,0xb5,0x07,0x1c,0xe4,0xdc,0x3d,
0xcc,0xaa,0xf7,0x81,0x47,0x67,0x2a,0x03,0xfc,0x33,
0x00,0x66,0xd5,0x75,0x1e,0x14,0x77,0xfd,0xd6,0x00,
0x00,0x00,0x00,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,
0x82,

  };


static gui_text_field_class_t gui_text_field_class = {
        YQRZ_5,
       YQRZ_6,

};




static gui_message_console_class_t gui_message_console_class = {
        YQRZ_20,
       YQRZ_21,
       YQRZ_22,

};




static gui_dir_list_class_t gui_dir_list_class = {
        YQRZ_17,
       YQRZ_18,
       YQRZ_19,

};




static gui_file_list_class_t gui_file_list_class = {
        YQRZ_13,
       YQRZ_14,
       YQRZ_15,
       YQRZ_16,

};




static gui_int_list_class_t gui_int_list_class = {
        YQRZ_25,
       YQRZ_26,
       YQRZ_27,
       YQRZ_28,
       YQRZ_29,
       YQRZ_30,
       YQRZ_31,
       YQRZ_32,

};



 

 class VFLL7: public FXMainWindow
 {
  FXDECLARE(VFLL7)
 public:
  enum { ID_FIRST= FXMainWindow::ID_LAST,
         ID_SELF,
         
   YQRZ_35,

   YQRZ_37,

   YQRZ_39,

   YQRZ_41,

   YQRZ_43,

   YQRZ_45,

   YQRZ_47,

   YQRZ_49,
        YQRZ_52,

   
        YQRZ_57,

   

 YQRZ_62,

  
        YQRZ_68,

           

           

           

    
          
  
        

    YQRZ_127,

   YQRZ_132,

   YQRZ_137,

   YQRZ_142,

          YQRZ_148,

   
  YQRZ_154,

        YQRZ_161,

   
  YQRZ_168,

        YQRZ_175,

   
  

        YQRZ_189,

    
  
 
    YQRZ_206,
  

  YQRZ_217,

 };
  
  int radio1_store;
 // FIXME: I should find some prefix and not use the suffix _store..
   
 FYRadioGroup *radio1;

   long YQRZ_36(FXObject *object,FXSelector sel, void *arg);

   long YQRZ_38(FXObject *object,FXSelector sel, void *arg);

   long YQRZ_40(FXObject *object,FXSelector sel, void *arg);

   long YQRZ_42(FXObject *object,FXSelector sel, void *arg);

   long YQRZ_44(FXObject *object,FXSelector sel, void *arg);

   long YQRZ_46(FXObject *object,FXSelector sel, void *arg);

   long YQRZ_48(FXObject *object,FXSelector sel, void *arg);

   long YQRZ_50(FXObject *object,FXSelector sel, void *arg);


  long YQRZ_55(FXObject *object,FXSelector sel, void *arg);

 FXButton *cool_button;


  long YQRZ_60(FXObject *object,FXSelector sel, void *arg);

 FXButton *foo_button;


  long YQRZ_65(FXObject *object,FXSelector sel, void *arg);

 FXButton *allnew;


  long YQRZ_71(FXObject *object,FXSelector sel, void *arg);



  



  



  


  





 FXTextField *source_dir;


  

      long YQRZ_130(FXObject *object,FXSelector sel, void *arg);
      long YQRZ_135(FXObject *object,FXSelector sel, void *arg);
      long YQRZ_140(FXObject *object,FXSelector sel, void *arg);
      long YQRZ_145(FXObject *object,FXSelector sel, void *arg);


  long YQRZ_151(FXObject *object,FXSelector sel, void *arg);

 

  FXList *numbers;


  long YQRZ_157(FXObject *object,FXSelector sel,void* arg);
  



  long YQRZ_164(FXObject *object,FXSelector sel, void *arg);


  FXList *strings;


  
  long YQRZ_172(FXObject *object,FXSelector sel,void* arg);



  long YQRZ_178(FXObject *object,FXSelector sel, void *arg);


  FXList *string_keys;


  
  



  long YQRZ_192(FXObject *object,FXSelector sel, void *arg);

 FXText *econ;
 

   

 FXDirList *dirs;

   long YQRZ_209(FXObject *object,FXSelector sel,void *arg);
   

 FXFileList *files;

  long YQRZ_220(FXObject *object,FXSelector sel,void* arg);
  

 FXList *newilist;

  VFLL7(FXApp* a,const FXString& name,
         FXIcon *ic,FXIcon *mi,FXuint opts,
         FXint x,FXint y,FXint w,FXint h,
         FXint pl,FXint pr,FXint pt,FXint pb,
         FXint hs,FXint vs);
  virtual ~VFLL7();
  VFLL7() : FXMainWindow() { }
  long handle_close(FXObject *object,FXSelector sel, void *arg);
 };

 FXDEFMAP(VFLL7) YQRZ_226 []= {
  FXMAPFUNC(SEL_CLOSE, VFLL7::ID_SELF, VFLL7::handle_close),
  
  
    FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_35, VFLL7::YQRZ_36),
  

  
    FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_37, VFLL7::YQRZ_38),
  

  
    FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_39, VFLL7::YQRZ_40),
  

  
    FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_41, VFLL7::YQRZ_42),
  

  
    FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_43, VFLL7::YQRZ_44),
  

  
    FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_45, VFLL7::YQRZ_46),
  

  
    FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_47, VFLL7::YQRZ_48),
  

  
    FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_49, VFLL7::YQRZ_50),
  

 
   FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_52, VFLL7::YQRZ_55),
 


 
   FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_57, VFLL7::YQRZ_60),
 


 
    FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_62, VFLL7::YQRZ_65),


 
   FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_68, VFLL7::YQRZ_71),
 


 


 


 


  

 


 


  FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_127, VFLL7::YQRZ_130),
 


  FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_132, VFLL7::YQRZ_135),
 


  FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_137, VFLL7::YQRZ_140),
 


  FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_142, VFLL7::YQRZ_145),
 


 
   FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_148, VFLL7::YQRZ_151),
 


  
     FXMAPFUNC(SEL_CLICKED,VFLL7::YQRZ_154,VFLL7::YQRZ_157),
  


 
   FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_161, VFLL7::YQRZ_164),
 


  
  
     FXMAPFUNC(SEL_DOUBLECLICKED,VFLL7::YQRZ_168,VFLL7::YQRZ_172),


 
   FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_175, VFLL7::YQRZ_178),
 


  
  


 
   FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_189, VFLL7::YQRZ_192),
 


  

  
    FXMAPFUNC(SEL_COMMAND, VFLL7::YQRZ_206, VFLL7::YQRZ_209), 
  


  
     FXMAPFUNC(SEL_CLICKED,VFLL7::YQRZ_217,VFLL7::YQRZ_220),
  
  


 }; 

 FXIMPLEMENT(VFLL7, FXMainWindow, YQRZ_226, ARRAYNUMBER(YQRZ_226))

 // FIXME: the argument names must be changed so that
 // we can have widgets called 'y' etc.
 VFLL7::VFLL7(
         FXApp* a,const FXString& name,
         FXIcon *ic,FXIcon *mi,FXuint opts,
         FXint x,FXint y,FXint w,FXint h,
         FXint pl,FXint pr,FXint pt,FXint pb,
         FXint hs,FXint vs) :
               FXMainWindow(a,name, ic,mi,opts,
                            x,y,w,h, pl,pr,pt,pb, hs,vs)

 {
   setTarget(this);
   setSelector(ID_SELF);
   
  FYRadioGroup *YQRZ_34;
  YQRZ_34= radio1 = (FYRadioGroup*) malloc(sizeof(* YQRZ_34));
  YQRZ_34->target= & radio1_store;
  YQRZ_34->head= NULL;


   FXMenuBar *VFLL4= new FXMenuBar(this, LAYOUT_SIDE_TOP|LAYOUT_FILL_X);

   FXMenuPane *VFLL1= new FXMenuPane(this); 
 
   new FXMenuCommand(VFLL1,"&Open",NULL,
      this ,
      YQRZ_35 );


   new FXMenuCommand(VFLL1,"&Close",NULL,
      this ,
      YQRZ_37 );


   new FXMenuCommand(VFLL1,"Quit",NULL,
      this ,
      YQRZ_39 );


   new FXMenuTitle(VFLL4, "&File",NULL, VFLL1);

   FXMenuPane *VFLL2= new FXMenuPane(this); 
 
   new FXMenuCommand(VFLL2,"Cu&t",NULL,
      this ,
      YQRZ_41 );


   new FXMenuCommand(VFLL2,"Paste",NULL,
      this ,
      YQRZ_43 );


   new FXMenuCommand(VFLL2,"Replace",NULL,
      this ,
      YQRZ_45 );


   new FXMenuTitle(VFLL4, "&Edit",NULL, VFLL2);

   FXMenuPane *VFLL3= new FXMenuPane(this); 
 
   new FXMenuCommand(VFLL3,"Contents",NULL,
      this ,
      YQRZ_47 );


   new FXMenuCommand(VFLL3,"About",NULL,
      this ,
      YQRZ_49 );


   new FXMenuTitle(VFLL4, "&Help",NULL, VFLL3);

  FXVerticalFrame *YQRZ_225= new
    FXVerticalFrame( this,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  LAYOUT_FILL_Y|
  
    

        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        , DEFAULT_SPACING,
        DEFAULT_SPACING);
   
  FXHorizontalFrame *YQRZ_72= new
    FXHorizontalFrame( YQRZ_225,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  
  
    

        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        , DEFAULT_SPACING,
        DEFAULT_SPACING);
   

  FXButton *YQRZ_51;

  YQRZ_51= cool_button =
    new FXButton(YQRZ_72,
      "hello!",
      NULL,
      this ,
      YQRZ_52 ,

  
  
  
  

  LAYOUT_LEFT |
  
  
  

  LAYOUT_FILL_X|
  
  
    

 
        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

    0,0,0,0, // x,y,w,h
  12,
  12,
  12,
  12

        );


   YQRZ_51->setBackColor(FXRGB(0x00,0x00,0xff)); 


 



  FXButton *YQRZ_56;

  YQRZ_56= foo_button =
    new FXButton(YQRZ_72,
      "bye!",
      NULL,
      this ,
      YQRZ_57 ,

  
  
  
  

  LAYOUT_LEFT |
  
  
  

  
  LAYOUT_FILL_Y|
  
    

 
        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

    0,0,0,0, // x,y,w,h
  12,
  12,
  12,
  12

        );


  


 
      FXFontDesc YQRZ_58;
      YQRZ_56->getFont()->getFontDesc(YQRZ_58);
      
         YQRZ_58.size= 32 * 10;
      
       strcpy(YQRZ_58.face, "Courier New");
      
      
      

      YQRZ_59= new FXFont(FXApp::instance(), YQRZ_58);
      YQRZ_56->setFont(YQRZ_59);
      

  FXButton *YQRZ_61;

  YQRZ_61= allnew =
    new FXButton(YQRZ_72,
      "new-button",
      NULL,
      this ,
      YQRZ_62 ,

        
        
        
        

        
        
        
        

        
        LAYOUT_FILL_Y|
 
        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

    YQRZ_61->setBackColor(FXRGB(0xff,0x00,0xff)); 

   
      FXFontDesc YQRZ_63;
      YQRZ_61->getFont()->getFontDesc(YQRZ_63);
      
      
       YQRZ_63.slant= FXFont::Italic;
      
      

      YQRZ_64= new FXFont(FXApp::instance(), YQRZ_63);
      YQRZ_61->setFont(YQRZ_64);
      

  FXButton *YQRZ_67;

  YQRZ_67= 
    new FXButton(YQRZ_72,
      "Builtin Button",
      VFLL5,
      this ,
      YQRZ_68 ,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  
  
    

 
        FRAME_THICK |
        ICON_ABOVE_TEXT |
        JUSTIFY_LEFT |
        JUSTIFY_CENTER_Y ,

    0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );


   YQRZ_67->setBackColor(FXRGB(0xff,0x00,0x00)); 


 
      FXFontDesc YQRZ_69;
      YQRZ_67->getFont()->getFontDesc(YQRZ_69);
      
         YQRZ_69.size= 20 * 10;
      
       strcpy(YQRZ_69.face, "Courier New");
      
      
      

      YQRZ_70= new FXFont(FXApp::instance(), YQRZ_69);
      YQRZ_67->setFont(YQRZ_70);
      
  FXHorizontalFrame *YQRZ_94= new
    FXHorizontalFrame( YQRZ_225,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  
  
    

        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        , DEFAULT_SPACING,
        DEFAULT_SPACING);
   

  FXButton *YQRZ_74;

  YQRZ_74= 
    new FXButton(YQRZ_94,
      "row2-1",
      VFLL6,
       NULL,
       0,

  
  
  
  

  
  
  
  

  
  
  
    

 
        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

    0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );


  


 



  FXButton *YQRZ_79;

  YQRZ_79= 
    new FXButton(YQRZ_94,
      "row2-2",
      NULL,
       NULL,
       0,

  
  
  
  

  
  
  
  

  
  
  
    

 
        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

    0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );


  


 



  FXButton *YQRZ_84;

  YQRZ_84= 
    new FXButton(YQRZ_94,
      "row2-3",
      NULL,
       NULL,
       0,

  
  
  
  

  
  
  
  

  
  
  
    

 
        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

    0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );


  


 



  FXToggleButton *YQRZ_89;

  YQRZ_89= 
    new FXToggleButton(YQRZ_94,
      "OFF", "ON", 
      NULL, NULL,
       NULL,
       0,

  
  
  
  

  
  
  
  

  
  
  
    

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        
        ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );

 

  




  FXLabel *YQRZ_95;

  YQRZ_95= 
    new FXLabel(YQRZ_225, "Separator Below", NULL,

  
  
  
  

  
  
  
  

  
  
  
    

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );

 
  
    new 
        FXHorizontalSeparator (YQRZ_225,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  
  
    

        SEPARATOR_GROOVE,
        0,0,0,0, // x,y,w,h
  0,
  0,
  0,
  0

        );
  

  FXLabel *YQRZ_98;

  YQRZ_98= 
    new FXLabel(YQRZ_225, "Separator Above", NULL,

  
  
  
  

  
  
  
  

  
  
  
    

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );

 
  
  FXHorizontalFrame *YQRZ_112= new
    FXHorizontalFrame( YQRZ_225,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  
  
    

        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        , DEFAULT_SPACING,
        DEFAULT_SPACING);
   

  FXLabel *YQRZ_101;

  YQRZ_101= 
    new FXLabel(YQRZ_112, "Source Directory", NULL,

  
  
  
  

  
  
  
  

  
  
  
    

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );

 
  
  FXTextField *YQRZ_104;
  source_dir = YQRZ_104= 
    new FXTextField(YQRZ_112,
      40,  NULL,
                         0,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  
  
    

    FRAME_SUNKEN|FRAME_THICK |
    JUSTIFY_LEFT | JUSTIFY_CENTER_Y |
    
    
    0,
    0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );


  FXButton *YQRZ_107;

  YQRZ_107= 
    new FXButton(YQRZ_112,
      "Browse..",
      NULL,
       NULL,
       0,

  
  
  
  

  
  
  
  

  
  
  
    

 
        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

    0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );


  


 


  FXHorizontalFrame *YQRZ_125= new
    FXHorizontalFrame( YQRZ_225,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  
  
    

        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        , DEFAULT_SPACING,
        DEFAULT_SPACING);
   

  FXLabel *YQRZ_113;

  YQRZ_113= 
    new FXLabel(YQRZ_125, "A spinner", NULL,

  
  
  
  

  
  
  
  

  
  
  
    

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );

 
  
  FXSpinner *YQRZ_116;
  YQRZ_116= 
    new FXSpinner(YQRZ_125, 3,
       // target and selector
       NULL, 0,

  
  
  
  

  
  
  
  

  
  
  
    

       // there are some options, but I dont know how to use those yet.
        0 | SPIN_NORMAL,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );

    
      YQRZ_116->setRange(3, 20);
    
    

 
  

  FXLabel *YQRZ_119;

  YQRZ_119= 
    new FXLabel(YQRZ_125, "Float spinner", NULL,

  
  
  
  

  
  
  
  

  
  
  
    

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );

 
  

  FXRealSpinner *YQRZ_122;
  YQRZ_122= 
    new FXRealSpinner(YQRZ_125, 3,
       // target and selector
       NULL, 0,

  
  
  
  

  
  
  
  

  
  
  
    

        0 |
        
        
       // there are some options, but I dont know how to use those yet.
        SPIN_NORMAL,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );

     YQRZ_122->setRange(4.15, 9.21);
     YQRZ_122->setIncrement(0.02); 

 
  
  FXGroupBox *YQRZ_152;
  YQRZ_152= new FXGroupBox(YQRZ_225, "Selection", 
        GROUPBOX_TITLE_LEFT |  // FIXME: this shall be configurable

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  
  
    

        FRAME_LINE |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,
     0,0,0,0, // xywh
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING);
   
  FXHorizontalFrame *YQRZ_146= new
    FXHorizontalFrame( YQRZ_152,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  
  
    

        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        , DEFAULT_SPACING,
        DEFAULT_SPACING);
   

  FXRadioButton * YQRZ_126;
  YQRZ_126= new FXRadioButton(YQRZ_146, "Foo 1", this, YQRZ_127, 

  
  
  
  

  
  
  
  

  
  
  
    

        FRAME_NONE |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );

    radio_append( radio1, YQRZ_126, 1 );
     YQRZ_126->setCheck(TRUE); radio1_store= 1; 
    


 



  FXRadioButton * YQRZ_131;
  YQRZ_131= new FXRadioButton(YQRZ_146, "Foo 2", this, YQRZ_132, 

  
  
  
  

  
  
  
  

  
  
  
    

        FRAME_NONE |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );

    radio_append( radio1, YQRZ_131, 4 );
    
     YQRZ_131->setCheck(FALSE); 


 



  FXRadioButton * YQRZ_136;
  YQRZ_136= new FXRadioButton(YQRZ_146, "Foo 3", this, YQRZ_137, 

  
  
  
  

  
  
  
  

  
  
  
    

        FRAME_NONE |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );

    radio_append( radio1, YQRZ_136, 9 );
    
     YQRZ_136->setCheck(FALSE); 


 



  FXRadioButton * YQRZ_141;
  YQRZ_141= new FXRadioButton(YQRZ_146, "Foo 4", this, YQRZ_142, 

  
  
  
  

  
  
  
  

  
  
  
    

        FRAME_NONE |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );

    radio_append( radio1, YQRZ_141, 16 );
    
     YQRZ_141->setCheck(FALSE); 


 



  FXButton *YQRZ_147;

  YQRZ_147= 
    new FXButton(YQRZ_152,
      "Print Selected..",
      NULL,
      this ,
      YQRZ_148 ,

  
  
  
  

  
  
  
  

  
  
  
    

 
        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

    0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );


  


 


  FXTabBook *YQRZ_195;
  YQRZ_195=  new FXTabBook(YQRZ_225,
           NULL, 0, // selector stuff

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  
  
    

        0, // FIXME: do the tab-side stuff.
        0,0,0,0, // xywh
  DEFAULT_SPACING,
  DEFAULT_SPACING,
  DEFAULT_SPACING,
  DEFAULT_SPACING

        );
   
  FXTabItem *YQRZ_166;
  YQRZ_166= new FXTabItem(YQRZ_195, "Int Keys", NULL);
  // FIXME: do the fonts here

  FXVerticalFrame *YQRZ_165= new
    FXVerticalFrame( YQRZ_195,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  LAYOUT_FILL_Y|
  
    

        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        , DEFAULT_SPACING,
        DEFAULT_SPACING);
   
   FXList *YQRZ_153; 

   YQRZ_153= numbers = new FXList(YQRZ_165,
        this
           ,
        YQRZ_154
           ,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  LAYOUT_FILL_Y|
  
    

           0
            ,0,0,0,0); // xywh


 



  FXButton *YQRZ_160;

  YQRZ_160= 
    new FXButton(YQRZ_165,
      "Test",
      NULL,
      this ,
      YQRZ_161 ,

  
  
  
  

  
  
  
  

  
  
  
    

 
        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

    0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );


  


 


  FXTabItem *YQRZ_180;
  YQRZ_180= new FXTabItem(YQRZ_195, "No Keys", NULL);
  // FIXME: do the fonts here

  FXVerticalFrame *YQRZ_179= new
    FXVerticalFrame( YQRZ_195,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  LAYOUT_FILL_Y|
  
    

        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        , DEFAULT_SPACING,
        DEFAULT_SPACING);
   
   FXList *YQRZ_167; 

   YQRZ_167= strings = new FXList(YQRZ_179,
        this
           ,
        YQRZ_168
           ,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  LAYOUT_FILL_Y|
  
    

           0
            ,0,0,0,0); // xywh


 



  FXButton *YQRZ_174;

  YQRZ_174= 
    new FXButton(YQRZ_179,
      "Test",
      NULL,
      this ,
      YQRZ_175 ,

  
  
  
  

  
  
  
  

  
  
  
    

 
        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

    0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );


  


 


  FXTabItem *YQRZ_194;
  YQRZ_194= new FXTabItem(YQRZ_195, "String Keys", NULL);
  // FIXME: do the fonts here

  FXVerticalFrame *YQRZ_193= new
    FXVerticalFrame( YQRZ_195,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  LAYOUT_FILL_Y|
  
    

        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        , DEFAULT_SPACING,
        DEFAULT_SPACING);
   
   FXList *YQRZ_181; 

   YQRZ_181= string_keys = new FXList(YQRZ_193,
        
           NULL,
        
           0,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  LAYOUT_FILL_Y|
  
    

           0
            ,0,0,0,0); // xywh


 



  FXButton *YQRZ_188;

  YQRZ_188= 
    new FXButton(YQRZ_193,
      "Test",
      NULL,
      this ,
      YQRZ_189 ,

  
  
  
  

  
  
  
  

  
  
  
    

 
        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

    0,0,0,0, // x,y,w,h
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD,
  DEFAULT_PAD

        );


  


 


  FXText *YQRZ_196;
  YQRZ_196= econ = new FXText(
       YQRZ_225, NULL,0, // target & selector

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  
  
    

        TEXT_WORDWRAP |
        VSCROLLER_ALWAYS |
        TEXT_READONLY | TEXT_AUTOSCROLL |
        0,
      0,0,0,0,  // x,y,w,h
           // FIXME: these are given as number constants in the
           // FXText constructor. Nothing symbolic like DEFAULT_PAD
           // etc. is used. So, I will do the same unwillingly.
     3,
     3,
     2,
     2);

 
  

  FXTabBook *YQRZ_224;
  YQRZ_224=  new FXTabBook(YQRZ_225,
           NULL, 0, // selector stuff

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  LAYOUT_FILL_Y|
  
    

        0, // FIXME: do the tab-side stuff.
        0,0,0,0, // xywh
  DEFAULT_SPACING,
  DEFAULT_SPACING,
  DEFAULT_SPACING,
  DEFAULT_SPACING

        );
   
  FXTabItem *YQRZ_204;
  YQRZ_204= new FXTabItem(YQRZ_224, "Directories", NULL);
  // FIXME: do the fonts here

  FXDirList *YQRZ_199;
  YQRZ_199= dirs = new FXDirList(YQRZ_224,
            NULL,
            0,
             TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|TREELIST_BROWSESELECT|
             DIRLIST_NO_OWN_ASSOC |
              
              

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  LAYOUT_FILL_Y|
  
    

             FRAME_RAISED|FRAME_THICK 
           ,0,0,0,0);  // xywh

 


  FXTabItem *YQRZ_215;
  YQRZ_215= new FXTabItem(YQRZ_224, "Files", NULL);
  // FIXME: do the fonts here


  FXFileList *YQRZ_205;
  YQRZ_205= files = new FXFileList(YQRZ_224,
           this
           ,
           YQRZ_206
           ,
             FILELIST_NO_OWN_ASSOC |
           
           

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  LAYOUT_FILL_Y|
  
    

           FRAME_RAISED|FRAME_THICK 
           ,0,0,0,0);  // xywh

 


  FXTabItem *YQRZ_223;
  YQRZ_223= new FXTabItem(YQRZ_224, "int list -new", NULL);
  // FIXME: do the fonts here

   FXList *YQRZ_216; 

   YQRZ_216= newilist = new FXList(YQRZ_224,
        this ,
        YQRZ_217 ,

  
  
  
  

  
  
  
  

  LAYOUT_FILL_X|
  LAYOUT_FILL_Y|
  
    

           0 ,0,0,0,0); // xywh

 






 }
 VFLL7:: ~ VFLL7() { }
 long VFLL7::handle_close
    (FXObject *object,FXSelector sel, void *arg)
 {
    /* window closing code would go here */
    return 0;
 } 
 
   
     long VFLL7::YQRZ_36
          (FXObject *object,FXSelector sel, void *arg)
          {  printf("Menu.Open\n");   return 1; }
   

   
     long VFLL7::YQRZ_38
          (FXObject *object,FXSelector sel, void *arg)
          {  printf("Menu.Close\n");  return 1; }
   

   
     long VFLL7::YQRZ_40
          (FXObject *object,FXSelector sel, void *arg)
          {  printf("Menu.Quit\n");   return 1; }
   

   
     long VFLL7::YQRZ_42
          (FXObject *object,FXSelector sel, void *arg)
          {  printf("Menu.Cut\n");   return 1; }
   

   
     long VFLL7::YQRZ_44
          (FXObject *object,FXSelector sel, void *arg)
          {  printf("Menu.Paste\n");  return 1; }
   

   
     long VFLL7::YQRZ_46
          (FXObject *object,FXSelector sel, void *arg)
          {  printf("Menu.Replace\n");   return 1; }
   

   
     long VFLL7::YQRZ_48
          (FXObject *object,FXSelector sel, void *arg)
          {  printf("Menu.Contents\n");   return 1; }
   

   
     long VFLL7::YQRZ_50
          (FXObject *object,FXSelector sel, void *arg)
          {  printf("Menu.About\n");   return 1; }
   

  
    long VFLL7::YQRZ_55
      (FXObject *object,FXSelector sel, void *arg)
         { printf("helloo!\n"); press_hello();  return 1; }
  


  
    long VFLL7::YQRZ_60
      (FXObject *object,FXSelector sel, void *arg)
         { printf("byyeee!\n"); press_bye();  return 1; }
  




  long VFLL7::YQRZ_65
    (FXObject *object,FXSelector sel, void *arg)
       {  printf("New button click!\n");
                             test_new_button();  return 1; }



  
    long VFLL7::YQRZ_71
      (FXObject *object,FXSelector sel, void *arg)
         {  printf("builtin click\n");  return 1; }
  


  


  


  


  


  


  



long VFLL7::YQRZ_130
  (FXObject *object,FXSelector sel, void *arg)
{
  radio_set_value( radio1, 1 );
   printf("First one.\n"); 
  // FIXME: put the on_click stuff here
  return 1;
}



long VFLL7::YQRZ_135
  (FXObject *object,FXSelector sel, void *arg)
{
  radio_set_value( radio1, 4 );
   printf("Second one.\n");
  // FIXME: put the on_click stuff here
  return 1;
}



long VFLL7::YQRZ_140
  (FXObject *object,FXSelector sel, void *arg)
{
  radio_set_value( radio1, 9 );
   printf("Third one.\n");
  // FIXME: put the on_click stuff here
  return 1;
}



long VFLL7::YQRZ_145
  (FXObject *object,FXSelector sel, void *arg)
{
  radio_set_value( radio1, 16 );
   printf("Fourth one.\n");
  // FIXME: put the on_click stuff here
  return 1;
}


  
    long VFLL7::YQRZ_151
      (FXObject *object,FXSelector sel, void *arg)
         {  printf("Selected: %d\n", radio1_store);  return 1; }
  



 long VFLL7::YQRZ_157
    (FXObject *object,FXSelector sel, void *arg)
    {
      FXList *YQRZ_159= (FXList*)(object);
      int clicked_item= (intptr_t) (arg);
      FYListItem *item= (FYListItem*) (YQRZ_159->getItem(clicked_item));

      int clicked_key = item->data_i;
      
      
      
      
                printf("clicked item %d: key= %d\n", clicked_item,
                                                     clicked_key);
             
      return 1;
    }





  
    long VFLL7::YQRZ_164
      (FXObject *object,FXSelector sel, void *arg)
         {  test_int_list();  return 1; }
  




 long VFLL7::YQRZ_172
    (FXObject *object,FXSelector sel, void *arg)
    {
      FXList *YQRZ_173= (FXList*)(object);
      int clicked_item= (intptr_t) (arg);
      FYListItem *item= (FYListItem*) (YQRZ_173->getItem(clicked_item));

      
      
      
      
      
                printf("Double click!\n");
             
      return 1;
    }




  
    long VFLL7::YQRZ_178
      (FXObject *object,FXSelector sel, void *arg)
         {  test_dispstr_list();  return 1; }
  







  
    long VFLL7::YQRZ_192
      (FXObject *object,FXSelector sel, void *arg)
         {  test_str_list();  return 1; }
  


  



  
long VFLL7::YQRZ_209
     (FXObject *object, FXSelector sel, void *arg)
{
   FXFileList *YQRZ_211= (FXFileList*) object;
   int YQRZ_212= (intptr_t) arg;
   FXString YQRZ_213= YQRZ_211->getItemPathname(YQRZ_212);
   const char *clicked_path=YQRZ_213.text(); 
   FXString YQRZ_214= YQRZ_211->getItemFilename(YQRZ_212);
   const char *clicked_name= YQRZ_214.text();
   if (YQRZ_211->isItemFile(YQRZ_212))
   {
       printf("File: %s : %s\n",  clicked_path,
                                                      clicked_name); 
      return 1;
   }
   if (YQRZ_211->isItemDirectory(YQRZ_212))
   {
       files->setDirectory(clicked_path); 
      return 1;
   }
   return 1;
}
  


  


  
long VFLL7::YQRZ_220(FXObject *object,FXSelector sel, void *arg)
    {
      FXList *YQRZ_222= (FXList*)(object);
      int clicked_item= (intptr_t) (arg);
      FYListItem_i *item= (FYListItem_i*) (YQRZ_222->getItem(clicked_item));
      int clicked_key = item->data_i;
       printf("new-list clicked on key %d\n",
                                    clicked_key); 
      return 1;
    }
  
  
  




  

 gui_testmain_t *gui_c_testmain()
 {
    // ffo -> fox form object
    // ifo -> interface form object 
   VFLL7 *ffo;
   gui_testmain_t * ifo;
   ffo= new VFLL7(
       FXApp::instance(),
       "good window",
       NULL, NULL, // FIXME: icons
       DECOR_ALL ,
       0, 0,
       410, 925,
       0, 0,
       0, 0,
       0, 0);
   // If the application has not been created, this will done
   // when the application gets created. Otherwise, we have
   // to explicitly do this.
   if (app_created) 
     ffo->create();
   
   ffo->show(PLACEMENT_SCREEN);

   ifo= (typeof(ifo)) malloc(sizeof(*ifo));
   ifo->self= ffo;
    
  ifo->radio1.widget= ffo->radio1;
  ifo->radio1.cls= & gui_radio_group_class;
 
  ifo->cool_button.widget= ffo->cool_button;
  ifo->cool_button.cls= & gui_button_class;
 
  ifo->foo_button.widget= ffo->foo_button;
  ifo->foo_button.cls= & gui_button_class;
 
  ifo->allnew.widget= ffo->allnew;
  ifo->allnew.cls= & gui_newbutton_class;
 
  ifo->source_dir.widget= ffo->source_dir;
  ifo->source_dir.cls= & gui_text_field_class;

  
    ifo->numbers.cls= & gui_intlist_class;
    ifo->numbers.widget= ffo->numbers;
   


  
    ifo->strings.cls= & gui_sslist_class;
    ifo->strings.widget= ffo->strings;
   


  
    ifo->string_keys.cls= & gui_slist_class;
    ifo->string_keys.widget= ffo->string_keys;
   

 
  ifo->econ.widget= ffo->econ;
  ifo->econ.cls= & gui_message_console_class;
 
  ifo->dirs.widget= ffo->dirs;
  ifo->dirs.cls= & gui_dir_list_class;
 
  ifo->files.widget= ffo->files;
  ifo->files.cls= & gui_file_list_class;
 
  ifo->newilist.widget= ffo->newilist;
  ifo->newilist.cls= & gui_int_list_class;

   return ifo;
 }




static FXApp *app;

void gui_init(int *argc,char **argv)
{
  app= new FXApp("YAK", "KUT");
  app->init(*argc, argv);
  app->create();
  
  VFLL5= new FXPNGIcon(app, YQRZ_66);
  VFLL5->create();

  VFLL6= new FXPNGIcon(app, YQRZ_73);
  VFLL6->create();

  app_created= 1;
}

void gui_run()
{
  app->run();
}

void gui_flush()
{
  app->runWhileEvents();
}



