#include <stdio.h>
#include <stdarg.h>
#include <stdlib.h>
#include <string.h>
#include "template.h"


enum tok_kind { tok_dummy, tok_text, tok_var, tok_reloc,
                tok_paren, tok_target };

static char *tok_names[]= { "dummy", "text", "var", "reloc",
                            "paren", "target" };

typedef struct token {
  struct token *prev, *next, *chpar;
  enum tok_kind kind;
  char *data;
} token_t;


struct tpl { token_t tokens; };

 typedef struct { token_t *dest; unsigned char* cursor; } state_t;

typedef struct {
  int selts;
  int tos;
  state_t *elts; 
} lexerstack_t;

lexerstack_t *lexerstack_new(int initial);
int lexerstack_empty(lexerstack_t *S);
void lexerstack_push(lexerstack_t *S, state_t V);
int lexerstack_pop(lexerstack_t *S, state_t* R);


lexerstack_t *lexerstack_new(int initial)
{
  lexerstack_t *S;
  S= malloc(sizeof(*S));
  S->selts= initial;
  S->tos= -1;
  S->elts= malloc(sizeof(state_t)*S->selts); 
  return S;
}

int lexerstack_empty(lexerstack_t *S)
  { return S->tos==-1; }

void lexerstack_push(lexerstack_t *S, state_t V)
{
  if(S->tos==S->selts-1) {
    S->selts+= S->selts/2;
    S->elts= realloc(S->elts, sizeof(state_t)*S->selts);
  }
  S->elts[++S->tos]= V;
}

int lexerstack_pop(lexerstack_t *S, state_t* R)
{
  if (S->tos==-1) return 0;
  if (R) *R= S->elts[S->tos];
  S->tos--;
  return 1;
}

#define REVERSE_VIDEO "\033[7m"
#define NORMAL_VIDEO  "\033[0m"


#define FOR_TOKENS(TPL, TOK)                          \
  do {                                                \
   TOK= TPL->tokens.next;                             \
   while(1) {                                         \
     while(TOK && TOK->kind==tok_dummy) {             \
       TOK= TOK->chpar;                               \
       if (!TOK) break;                               \
       TOK= TOK->next;                                \
     }                                                \
     if (!TOK) break;

#define END_FOR(TOK)                                  \
     if (TOK->kind==tok_paren) TOK=TOK->chpar;        \
     TOK=TOK->next;                                   \
   }                                                  \
  }                                                   \
  while(0);


typedef struct {
  char *key, *value;
} strpair_t;


typedef struct strtree_s strtree_t;


strtree_t *strtree_new();
int strtree_find(strtree_t *T, char*  key,  strpair_t *value);
int strtree_insert(strtree_t *T,  strpair_t data) ;
int strtree_remove(strtree_t *T, char*  key,  strpair_t *value);
int strtree_destroy(strtree_t *T, strpair_t *value);



typedef struct strtree_node {
   struct strtree_node *left, *right,*parent;
   int height;
    strpair_t data;
} strtree_node_t;

struct strtree_s {
  strtree_node_t *root;
};


strtree_node_t *strtree_find_node(strtree_t *T, char*  key2);
static void strtree_rebalance(strtree_t *T, strtree_node_t *N);
  
static void strtree_rotate_left(strtree_t *T, strtree_node_t *A);
static void strtree_rotate_left_twolevels(strtree_t *T, strtree_node_t *A);
static void strtree_rotate_right(strtree_t *T, strtree_node_t *A);
static void strtree_rotate_right_twolevels(strtree_t *T, strtree_node_t *A);
static int strtree_right_heavy(strtree_node_t *A);
static int strtree_left_heavy(strtree_node_t *A);
static void strtree_remove_node(strtree_t *T, strtree_node_t *N);
static strtree_node_t *strtree_remove_max(strtree_t *T,strtree_node_t *N);
static strtree_node_t *strtree_remove_min(strtree_t *T,strtree_node_t *N);
static void strtree_calculate_height(strtree_node_t *N);
static void strtree_replace_child_in_parent
    (strtree_t* T, strtree_node_t* old, strtree_node_t* nw);
static void strtree_set_left_child(strtree_node_t *P, strtree_node_t *N);
static void strtree_set_right_child(strtree_node_t *P, strtree_node_t *N);
static int strtree_height(strtree_node_t * A);

strtree_node_t *strtree_find_node(strtree_t *T, char*  key2)
{
   strtree_node_t *node;
   node= T->root;
   while(node) {
     int result;
      strpair_t data;
     char*  key; char*  key1;
     data= node->data;
     {  key= data.key;  }
     key1= key;
     {  result= strcmp(key1, key2);   }
     if (result==0) return node;
     else if (result<0) node= node->left;
     else node= node->right;
   }
   return 0;
}
static void strtree_rebalance(strtree_t *T, strtree_node_t *N)
{
  int u;
  strtree_node_t *P;

  strtree_calculate_height(N);

  u = strtree_height(N->left)-strtree_height(N->right);
  P = N->parent;
  if (u < -1) {
      if (strtree_left_heavy(N->right)) strtree_rotate_left_twolevels(T, N);
      else strtree_rotate_left(T, N);
  } else if (u > 1) {
      if (strtree_right_heavy(N->left)) strtree_rotate_right_twolevels(T, N);
      else strtree_rotate_right(T, N);
  }

  if (P) strtree_rebalance(T, P);
}

  
static void strtree_rotate_left(strtree_t *T, strtree_node_t *A)
{
  strtree_node_t *B;
  B = A->right;
  strtree_set_right_child(A, B->left);
  strtree_replace_child_in_parent(T, A, B);
  strtree_set_left_child(B, A);
  strtree_calculate_height(A);
  strtree_calculate_height(B);
}
static void strtree_rotate_left_twolevels(strtree_t *T, strtree_node_t *A)
{
  strtree_node_t *B, *C;

  B = A->right; C = B->left;
  strtree_set_right_child(A, C->left);
  strtree_set_left_child(B, C->right);
  strtree_replace_child_in_parent(T, A, C);
  strtree_set_left_child(C, A);
  strtree_set_right_child(C, B);
  strtree_calculate_height(A);
  strtree_calculate_height(B);
  strtree_calculate_height(C);
}

static void strtree_rotate_right(strtree_t *T, strtree_node_t *A)
{
  strtree_node_t *B;

  B = A->left;

  A->left = B->right;
  if (A->left) A->left->parent = A;

  B->parent = A->parent;
  strtree_replace_child_in_parent(T, A, B);

  B->right = A;
  A->parent = B;

  strtree_calculate_height(A);
  strtree_calculate_height(B);
}

static void strtree_rotate_right_twolevels(strtree_t *T, strtree_node_t *A)
{
  strtree_node_t *B, *C;

  B = A->left;
  C = B->right;
  /* we know that B and C are non-null since
     A was left heavy and B was right heavy */

  A->left = C->right;
  if (A->left) A->left->parent = A;

  B->right = C->left;
  if (B->right) B->right->parent = B;

  C->parent = A->parent;
  strtree_replace_child_in_parent(T, A, C);

  C->left = B;
  C->right = A;
  A->parent = C;
  B->parent = C;

  strtree_calculate_height(A);
  strtree_calculate_height(B);
  strtree_calculate_height(C);
}
static int strtree_right_heavy(strtree_node_t *A)
{
  if (!A) return 0;
  return (strtree_height(A->right)-strtree_height(A->left)) > 0;
}

static int strtree_left_heavy(strtree_node_t *A)
{
  if (!A) return 0;
  return (strtree_height(A->right)-strtree_height(A->left)) < 0;
}

static void strtree_remove_node(strtree_t *T, strtree_node_t *N)
{
   strtree_node_t *Z;
   if (!N->left && !N->right) {
     strtree_replace_child_in_parent(T, N, 0);
     if (N->parent) strtree_rebalance(T,N->parent);
   } else {
     if (strtree_left_heavy(N)) Z= strtree_remove_max(T,N->left);
     else Z= strtree_remove_min(T,N->right);
     strtree_replace_child_in_parent(T, N, Z);
     strtree_set_left_child(Z, N->left);
     strtree_set_right_child(Z, N->right);
     strtree_rebalance(T,Z);
   }
   free(N);
}
static strtree_node_t *strtree_remove_max(strtree_t *T,strtree_node_t *N)
{
   while(N->right) N= N->right;
   strtree_replace_child_in_parent(T, N, N->left);
   if (N->parent) strtree_rebalance(T,N->parent);
   return N;
}

static strtree_node_t *strtree_remove_min(strtree_t *T,strtree_node_t *N)
{
   while(N->left) N= N->left;
   strtree_replace_child_in_parent(T, N, N->right);
   if (N->parent) strtree_rebalance(T,N->parent);
   return N;
}

static void strtree_calculate_height(strtree_node_t *N)
{
  int lH, rH;
  lH= strtree_height(N->left);
  rH= strtree_height(N->right);
  if (lH>rH) N->height= lH+1; else N->height= rH+1;
}

static void strtree_replace_child_in_parent
    (strtree_t* T, strtree_node_t* old, strtree_node_t* nw)
{
  if (old->parent)
    {
      if (old->parent->left == old)
	old->parent->left = nw;
      else
	old->parent->right = nw;
    }
  else
    {
      T->root = nw;
    }
  if (nw) nw->parent= old->parent;
}

static void strtree_set_left_child(strtree_node_t *P, strtree_node_t *N)
{
  P->left= N; 
  if (N) N->parent= P;
}

static void strtree_set_right_child(strtree_node_t *P, strtree_node_t *N)
{
  P->right= N; 
  if (N) N->parent= P;
}

static int strtree_height(strtree_node_t * A)
{
  if (A) return A->height;
  else return 0;
}


strtree_t *strtree_new()
{
  strtree_t *T;
  T= malloc(sizeof(*T));
  T->root= 0;
  return T;
}


int strtree_find(strtree_t *T, char*  key,  strpair_t *value)
{
   strtree_node_t *n;
   n= strtree_find_node(T, key);
   if (n) { if (value) *value= n->data; return 1; }
   else return 0;
}

int strtree_insert(strtree_t *T,  strpair_t data) 
{
  strtree_node_t *N,*P,*K,**PL;
  char*  key; char*  key2; char*  key1;
  int result;

  N = calloc(1, sizeof(*N));
  N->data= data;
  N->height= 1;

  P = 0;
  PL= &T->root;
  K= T->root;
  {  key= data.key;  }
  key2= key;
  while (K) {
    data= K->data;
    {  key= data.key;  }
    key1= key;
    {  result= strcmp(key1, key2);  }
    if (result<0)      { PL= &K->left; P= K; K= K->left; }
    else if (result>0) { PL= &K->right; P= K; K= K->right; }
    else               { free(N); return 0; }
  }
  *PL= N;
  N->parent= P;
  strtree_rebalance(T, N);
  return 1;
}
int strtree_remove(strtree_t *T, char*  key,  strpair_t *value)
{
   strtree_node_t *N;
   N= strtree_find_node(T,key);
   if (!N) return 0;
   if (value) *value= N->data;
   strtree_remove_node(T,N);
   return 1;
}
int strtree_destroy(strtree_t *T, strpair_t *value)
{
   strtree_node_t *N= T->root;
   if (!N) return 0;
   while(N->left) N=N->left;
   if (value) *value= N->data;
   strtree_remove_node(T,N);
   return 1;
}



static token_t *token
  (token_t *head, enum tok_kind kind, unsigned char *start,unsigned char *end);
static void insert_B_before_A(token_t *A, token_t *B);
static void print_pos_exit(char *str, char *cursor);
static void print_tokenlist(token_t *head);
static void print_token(token_t *T);
static int tokenlist_to_str(token_t *head, char *buffer, int size);
static int token_to_str(token_t *T, char *buffer, int size);
static token_t *token_var(char *str);
static void remove_node(token_t *T);
static void generate_symbols(tpl_t *TPL);
static token_t *eval_builtin(token_t *input);
static int expand_def(token_t *arglist,token_t **Rfirst, token_t **Rlast);
static int expand_nef(token_t *arglist,token_t **Rfirst, token_t **Rlast);
static int expand_dev(token_t *arglist,token_t **Rfirst, token_t **Rlast);
static int all_spaces(token_t *arglist);
static int get_relocation(tpl_t *src, token_t **Rstart, token_t **Rend);
static int token_empty(token_t *T);
static int relocate(tpl_t *TPL, token_t *first, token_t *last);
static void tpl_append_tokens(tpl_t *TPL, token_t *first, token_t *last);
static token_t *tokenlist_copy(token_t *list);
static token_t *token_copy(token_t *src);
static char *tokenlist_convert_str(token_t *list);
static int expand_eq(token_t *arglist,token_t **Rfirst, token_t **Rlast);
static struct {
  char *name; int (*func)(token_t*,token_t **,token_t **);
} builtins[]= {
  { "$T", NULL },
  { "$F", NULL },
  { "$def", expand_def },
  { "$nef", expand_nef },
  { "$dev", expand_dev },
  { "$eq",  expand_eq },
  { 0, 0 }
};


static token_t *token
  (token_t *head, enum tok_kind kind, unsigned char *start,unsigned char *end)
{
  token_t *R;
  R=calloc(1,sizeof(*R));
  R->data= malloc(end-start+1);
  memcpy(R->data, start, end-start);
  R->data[end-start]= 0;
  R->kind= kind;
  if (head) insert_B_before_A(head, R);
  else R->prev= R->next= R; 
  return R;
}

static void insert_B_before_A(token_t *A, token_t *B)
{
  B->prev= A->prev;
  B->next= A;
  A->prev->next= B;
  A->prev= B;
}

static void print_pos_exit(char *str, char *cursor)
{
  fwrite(str, 1, cursor-str, stderr);
  fprintf(stderr,"%s)%s", REVERSE_VIDEO,NORMAL_VIDEO);
  fprintf(stderr,"%s", cursor+1);
  exit(1);
}

static void print_tokenlist(token_t *head)
{
  token_t *T;
  for(T=head->next;T!=head;T=T->next)
   print_token(T);
}

static void print_token(token_t *T)
{
  printf("[%s]%s", tok_names[T->kind], T->data);
  if (T->kind==tok_paren) {
    print_tokenlist(T->chpar);
    printf(")");
  }
}


static int tokenlist_to_str(token_t *head, char *buffer, int size)
{
  token_t *T;
  for(T=head->next;T!=head;T=T->next)
     size= token_to_str(T, buffer, size);
  return size;
}

static int token_to_str(token_t *T, char *buffer, int size)
{
  if (T->kind==tok_target) return size;
  int L= strlen(T->data);
  if (buffer) memcpy(buffer+size, T->data, L);
  size+= L;
  if (T->kind==tok_paren) {
    size= tokenlist_to_str(T->chpar, buffer, size);
    if (buffer) buffer[size]= ')';
    size++;
  }
  return size;
}


static token_t *token_var(char *str)
{
  token_t *T;
  T= calloc(1,sizeof(*T));
  T->kind= tok_var;
  T->data= str;
  return T;
}

static void remove_node(token_t *T)
{
  T->prev->next= T->next;
  T->next->prev= T->prev;
}


static void generate_symbols(tpl_t *TPL)
{
  token_t *T;
  strtree_t *symbols;
  symbols= strtree_new();
  FOR_TOKENS(TPL, T)
    if (T->kind==tok_var && T->data[1]=='G'
        && T->data[2]=='_' && T->data[3]!=0)
    {
      strpair_t entry;
      if (!strtree_find(symbols, T->data, &entry))
      {
        static int last= 1;
        char buf[50];
        sprintf(buf,"YQRZ_%d", last++);
        entry.key= T->data;
        entry.value= strdup(buf);
        strtree_insert(symbols, entry);
      }
      T->kind= tok_text;
      T->data= entry.value;
    }
  END_FOR(T)
  while(strtree_destroy(symbols,0));
  free(symbols);
}


static token_t *eval_builtin(token_t *input)
{
  token_t *T;
  if (input->kind==tok_text || input->kind==tok_reloc
                            || input->kind==tok_target )
     return input->next;
  if (input->kind==tok_dummy) return input; // just in case
  if (input->kind==tok_paren)
  {
    for(T=input->chpar->next;T!=input->chpar;T=eval_builtin(T)) ;
    return input->next;
  }
  // here input->kind== tok_var

  int i;
  for(i=0;builtins[i].name;i++)
     if (!strcmp(builtins[i].name,input->data)) break;
  if (!builtins[i].name) return input->next;

  token_t *anchor;
  token_t *arg;
  token_t *first, *last;

  arg= input->next;
  if (arg->kind!=tok_paren) return input->next;

  anchor= input->prev;

  remove_node(input);
  remove_node(arg);

  if (!strcmp(builtins[i].name,"$F")) goto done;
  if (!strcmp(builtins[i].name,"$T"))
     { first= arg->chpar->next; last= arg->chpar->prev; goto success; }

  for(T=arg->chpar->next;T!=arg->chpar;T=eval_builtin(T));

  if ((*builtins[i].func)(arg->chpar, &first, &last))
    goto success;

done:
  return anchor->next;

success:
  first->prev= anchor;
  last->next= anchor->next;
  anchor->next->prev= last;
  anchor->next= first;
  return first;
}

static int expand_def(token_t *arglist,token_t **Rfirst, token_t **Rlast)
{
  char *var;
  if (all_spaces(arglist)) var= "$F"; else var= "$T";
  *Rfirst= *Rlast= token_var(var);
  return 1;
}

static int expand_nef(token_t *arglist,token_t **Rfirst, token_t **Rlast)
{
  char *var;
  if (all_spaces(arglist)) var= "$T"; else var= "$F";
  *Rfirst= *Rlast= token_var(var);
  return 1;
}

static int expand_dev(token_t *arglist,token_t **Rfirst, token_t **Rlast)
{
  if (all_spaces(arglist))
  {
    *Rfirst= *Rlast= token_var("$T"); 
    return 1;
  } 

  insert_B_before_A(arglist, token_var("$F"));
  *Rfirst= arglist->next;
  *Rlast= arglist->prev;
  return 1;
}


static int all_spaces(token_t *arglist)
{
  token_t *T;
  for(T=arglist->next;T!=arglist;T=T->next) {
    if (T->kind==tok_var) continue;
    if (!token_empty(T)) return 0;
  } 
  return 1;
}


static int get_relocation(tpl_t *src, token_t **Rstart, token_t **Rend)
{
  token_t *list;
  list= &src->tokens;
  token_t *start, *end;

  while(1) 
  {
    start= list->next;
    if (start==list) return 0;
    if (start->kind==tok_reloc) break;
    if (!token_empty(start))
    {
       fprintf(stderr,"error: template doesn't start with a relocation\n");
       fprintf(stderr,"%s\n", tpl_to_str(src));
       exit(1);
    }
    remove_node(start);
  }

  for(end= start->next; end!=list && end->kind!=tok_reloc;end=end->next) ;
  *Rstart= start;
  *Rend= end->prev;

  end->prev= list;
  list->next= end;
  return 1;
}


static int token_empty(token_t *T)
{
  int i;
  for(i=0;T->data[i];i++) {
    unsigned char C= T->data[i];
    if (C<=32 || C==127) continue;
    return 0;
  }
  return 1;
}


static int relocate(tpl_t *TPL, token_t *first, token_t *last)
{
  token_t *T;
  char *name= first->data;
  if (first==last) return 1;
  FOR_TOKENS(TPL, T)
    if (T->kind==tok_target && !strcmp(T->data, name+1))
    {
       token_t *P= T->prev;
       first= first->next;
       P->next= first; first->prev= P;
       T->prev= last; last->next= T;
       return 1;
    }
  END_FOR(T)
  return 0;
}

static void tpl_append_tokens(tpl_t *TPL, token_t *first, token_t *last)
{
  token_t *tail, *head;

  head= &TPL->tokens; tail= head->prev;

  first->prev= tail; last->next= head;
  tail->next= first; head->prev= last;
}


static token_t *tokenlist_copy(token_t *list)
{
  token_t *ret;
  token_t *src;
  ret= calloc(1,sizeof(*ret));
  ret->prev= ret->next= ret;
  for(src=list->next;src!=list;src=src->next)
    insert_B_before_A(ret, token_copy(src));
  return ret;
}

static token_t *token_copy(token_t *src)
{
  token_t *T;
  T= calloc(1,sizeof(*T));
  T->kind= src->kind; T->data= src->data;
  if (src->kind!=tok_paren) return T;

  T->chpar= tokenlist_copy(src->chpar);
  T->chpar->chpar= T;
  return T;
}


static char *tokenlist_convert_str(token_t *list)
{
  int size;
  char *buffer;
  size= tokenlist_to_str(list, 0,0);
  buffer= malloc(size+1);
  tokenlist_to_str(list, buffer, 0);
  buffer[size]= 0;
  return buffer;
}

static int expand_eq(token_t *arglist,token_t **Rfirst, token_t **Rlast)
{
  char *var;
  char *arg;
  char *B,*C,*D;

  var= "$F";
  arg= tokenlist_convert_str(arglist);

  for(D=arg;D[0];D++)
    if (D[0]=='=') break;
  if (!D[0]) goto done; 

  for(B=arg,C=D+1;B!=D;B++,C++)
     if (C[0]!=B[0]) goto done;
  if (C[0]!=0) goto done;
  var= "$T";
done:
  free(arg);
  *Rfirst= *Rlast= token_var(var);
  return 1;
}


tpl_t *tpl_new(char *str)
{
  tpl_t *ret;
  unsigned char *cursor, *marker, *start;
  token_t *dest;
  ret= calloc(1,sizeof(*ret));
  ret->tokens.prev= ret->tokens.next= &ret->tokens;
  cursor= (unsigned char*) str;
  dest= &ret->tokens;
  lexerstack_t *states;
  states= lexerstack_new(50);

again:
  start= cursor;

/*!re2c
   re2c:yyfill:enable= 0;
   re2c:define:YYCTYPE= "unsigned char";
   re2c:define:YYCURSOR= cursor;
   re2c:define:YYMARKER= marker;
  LETTER=[A-Za-z_];
  DIGIT=[0-9];
  IDENT=(LETTER|DIGIT);
  DOLLAR="$";
  QUOT=[\042];
  ESCAPE=[\134];
  AT="@";
  SPACE=[\001-\040\177];
  OPEN="(";
  CLOSE=")";
  QCHAR=([^\042\134]|[\134].);
  EOF=([\000]);
  DOLLAR(LETTER)(IDENT)*  { token(dest, tok_var, start, cursor); goto again; }
  AT(LETTER)(IDENT)*     { token(dest, tok_reloc, start,cursor); goto again; }
  "<"(LETTER)(IDENT)*">" {
         token(dest, tok_target, start+1, cursor-1);
         goto again;
                         }
  QUOT(QCHAR)*QUOT       { token(dest, tok_text, start,cursor); goto again; }
  (SPACE)*OPEN            {
       token_t *self;
       state_t state;
       self= token(dest, tok_paren, start,cursor);
       self->chpar= calloc(1,sizeof(*self));
       self->chpar->prev= self->chpar->next= self->chpar;
       self->chpar->chpar= self;
       state.dest= dest; state.cursor= cursor-1;
       lexerstack_push(states, state);
       dest= self->chpar;
       goto again;
                          }
  CLOSE                   { 
       state_t state;
       if (!lexerstack_empty(states))
       {
         lexerstack_pop(states, &state);
         dest= state.dest;
         goto again;
       }
       fprintf(stderr,"Error: dangling right-parenthesis.\n");
       print_pos_exit(str, (char*) cursor);
                          }
  QUOT                    {
    fprintf(stderr,"Error: dangling quote character.\n");
    print_pos_exit(str, (char*) cursor);
                          }
  EOF                     {
     state_t state;
     if (lexerstack_empty(states)) goto all_done;
     lexerstack_pop(states, &state);
     fprintf(stderr,"Error: unmatched left parenthesis.\n");
     print_pos_exit(str, (char*) state.cursor);
                          }
  [^\042\000()$@<>]+     { token(dest,tok_text,start,cursor); goto again; } 
  [$@<>]                 { token(dest,tok_text,start,cursor); goto again; }
*/
all_done:
  return ret;
}


void tpl_print(tpl_t *T)
{
  print_tokenlist(&T->tokens);
}


char *tpl_to_str(tpl_t *T)
{
  return tokenlist_convert_str(&T->tokens);
}

void tpl_append(tpl_t *dest, tpl_t *src)
{
   token_t *Dhead, *Dlast;
   token_t *Sfirst, *Slast;

   Dhead= &dest->tokens; Dlast= Dhead->prev;
   Sfirst= src->tokens.next; Slast= src->tokens.prev;

   if (Sfirst==&src->tokens) return ;
   // if (Sfirst==Slast) { insert_B_before_A(Dhead, Sfirst); return ;

   Slast->next= Dhead;
   Dhead->prev= Slast;

   Sfirst->prev= Dlast;
   Dlast->next= Sfirst;
}


void tpl_replace(tpl_t *TPL,char *name, char *value)
{
  token_t *T;

  FOR_TOKENS(TPL,T)
   if (T->kind==tok_var && !strcmp(T->data,name))
   {
     T->kind= tok_text;
     T->data= value;
   }
  END_FOR(T)
  
}


void tpl_replace_i(tpl_t *T, char *name, int v)
{
  char buf[50];
  sprintf(buf,"%d", v);
  tpl_replace(T, name, strdup(buf));
}

void tpl_free(tpl_t *T)
{
  // We never free anything, man. That is how we roll.
}


void tpl_builtin(tpl_t *TPL)
{
  token_t *T;
  generate_symbols(TPL);
  for(T=TPL->tokens.next;T!=&TPL->tokens;T=eval_builtin(T));
}


void tpl_relocations(tpl_t *dest,tpl_t *src)
{
  token_t *first, *last;
  while(get_relocation(src, &first, &last))
  {
    if (!relocate(dest, first, last))
      tpl_append_tokens(dest, first, last);
  }
}


void tpl_relocations_known_only(tpl_t *dest, tpl_t *src)
{
  tpl_t temp;
  token_t *first, *last;
  temp.tokens.prev= temp.tokens.next= &temp.tokens;

  while(get_relocation(src, &first, &last))
  {
    if (!relocate(dest, first, last))
      tpl_append_tokens(&temp, first, last);
  }

  tpl_append(src, &temp);
}


void tpl_replace_var(tpl_t *TPL, char *name, char *var)
{
  token_t *T;
  FOR_TOKENS(TPL, T)
    if (T->kind==tok_var && !strcmp(T->data, name))
      T->data= var;
  END_FOR(T)
}


void tpl_replace_tpl(tpl_t *TPL, char *name, tpl_t *value)
{
   token_t *T;
   FOR_TOKENS(TPL, T)
      if (T->kind==tok_var && !strcmp(T->data, name))
      {
        token_t *P= T->prev;
        token_t *copy= tokenlist_copy(&value->tokens);
        token_t *first= copy->next; 
        token_t *last= copy->prev;
        if (first==copy)
        {
          remove_node(T);
          T= P->next; continue;
        }
        first->prev= P; last->next= T;
        P->next= first; T->prev= last; 
        remove_node(T);
        T= last->next;
        continue;
      }
   END_FOR(T)
}

void tpl_remove_targets(tpl_t *TPL)
{
  token_t *T;
  FOR_TOKENS(TPL,T)
    // CAUTION: This works only because we don't free T.
    // The loop uses T->next to iterate so that link must 
    // still be valid after the removal
    if (T->kind==tok_target)
    {
      T->prev->next= T->next;
      T->next->prev= T->prev;
    }
  END_FOR(T)
}


